@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cpphs
 version: 1.20.1
-id: cpphs-1.20.1-b531b91e3eedabd84a3f357cbe12d473
-key: cpphs_4BOba56UoHy4GZONxR3yKz
+id: cpphs-1.20.1-871062ee45047e2f85948c7199a03a26
+key: cpphs_6gGTLZlFKFj65mZSINKWFa
 license: LGPL
 copyright: 2004-2016, Malcolm Wallace
 maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
@@ -37,13 +37,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.20.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.20.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cpphs-1.20.1
-hs-libraries: HScpphs-1.20.1-4BOba56UoHy4GZONxR3yKz
+hs-libraries: HScpphs-1.20.1-6gGTLZlFKFj65mZSINKWFa
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
-    polyparse-1.11-e9f1a767e0f506fecd31d2edb677e294
+    polyparse-1.12-e6234a5638570dd6df9812cf7a8f00d9
 haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
 haddock-html: /usr/share/doc/haskell-cpphs/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
